@@ -255,10 +255,10 @@ void apxCmdlineFree(
 
 /*
  * Environment variables parsing
- * Each variable is prfixed with PR_
+ * Each variable is prefixed with PR_
  * for example 'set PR_JVM=auto' has a same meaning as providing '--Jvm auto'
  * on the command line.
- * Multistring variables are added to the present conf.
+ * Multi-string variables are added to the present conf.
  */
 void apxCmdlineLoadEnvVars(
     LPAPXCMDLINE lpCmdline)
@@ -275,10 +275,16 @@ void apxCmdlineLoadEnvVars(
         lstrlcatW(szEnv, 64, lpCmdline->lpOptions[i].szName);
         l = GetEnvironmentVariableW(szEnv, szVar, SIZ_HUGMAX);
         if (l == 0 || l >= SIZ_HUGMAX) {
-            if (l == 0 && GetLastError() != ERROR_ENVVAR_NOT_FOUND) {
-                apxLogWrite(APXLOG_MARK_ERROR "Error geting environment variable %S",
-                            szEnv);
-                return;
+            if (l == 0) {
+                if (GetLastError() == ERROR_ENVVAR_NOT_FOUND) {
+                    // Explicitly clear the error else it will be logged the
+                    // next time a log message is written
+                    SetLastError(0);
+                } else {
+                    apxLogWrite(APXLOG_MARK_ERROR "Error getting environment variable %S",
+                                szEnv);
+                    return;
+                }
             }
             ++i;
             continue;
